@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getDefinitions(vmanage):
     """
     Get policy definitions
@@ -13,8 +10,8 @@ def getDefinitions(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/fxsdidport"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/definition/fxsdidport"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def create(vmanage, policydefinition):
@@ -30,8 +27,8 @@ def create(vmanage, policydefinition):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/fxsdidport"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policydefinition)
+    endpoint = f"dataservice/template/policy/definition/fxsdidport"
+    response = vmanage.apiCall("POST", endpoint, policydefinition)
     return response
 
 def saveInBulk(vmanage, policydefinition):
@@ -47,8 +44,8 @@ def saveInBulk(vmanage, policydefinition):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/fxsdidport/bulk"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policydefinition)
+    endpoint = f"dataservice/template/policy/definition/fxsdidport/bulk"
+    response = vmanage.apiCall("PUT", endpoint, policydefinition)
     return response
 
 def editMultiple(vmanage, policydefinition, id):
@@ -65,8 +62,8 @@ def editMultiple(vmanage, policydefinition, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/fxsdidport/multiple/{id}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policydefinition)
+    endpoint = f"dataservice/template/policy/definition/fxsdidport/multiple/{id}"
+    response = vmanage.apiCall("PUT", endpoint, policydefinition)
     return response
 
 def preview(vmanage, policydefinition):
@@ -82,8 +79,8 @@ def preview(vmanage, policydefinition):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/fxsdidport/preview"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policydefinition)
+    endpoint = f"dataservice/template/policy/definition/fxsdidport/preview"
+    response = vmanage.apiCall("POST", endpoint, policydefinition)
     return response
 
 def previewById(vmanage, id):
@@ -99,8 +96,8 @@ def previewById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/fxsdidport/preview/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/definition/fxsdidport/preview/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def get(vmanage, id):
@@ -116,8 +113,8 @@ def get(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/fxsdidport/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/definition/fxsdidport/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def edit(vmanage, policydefinition, id):
@@ -134,8 +131,8 @@ def edit(vmanage, policydefinition, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/fxsdidport/{id}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policydefinition)
+    endpoint = f"dataservice/template/policy/definition/fxsdidport/{id}"
+    response = vmanage.apiCall("PUT", endpoint, policydefinition)
     return response
 
 def delete(vmanage, id):
@@ -151,6 +148,6 @@ def delete(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/definition/fxsdidport/{id}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/template/policy/definition/fxsdidport/{id}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
