@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def activate(vmanage):
     """
     Activate cluster to start working as primary
@@ -13,8 +10,8 @@ def activate(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/activate"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/activate"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def getClusterInfo(vmanage):
@@ -29,8 +26,8 @@ def getClusterInfo(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/clusterInfo"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/clusterInfo"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def restoreConfigDb(vmanage, payload):
@@ -46,8 +43,8 @@ def restoreConfigDb(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/dbrestore"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/disasterrecovery/dbrestore"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def getConfigDBRestoreStatus(vmanage):
@@ -62,8 +59,8 @@ def getConfigDBRestoreStatus(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/dbrestorestatus"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/dbrestorestatus"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def deleteLocalDC(vmanage):
@@ -78,8 +75,8 @@ def deleteLocalDC(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/deleteLocalDataCenter"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/deleteLocalDataCenter"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def deleteDC(vmanage):
@@ -94,8 +91,8 @@ def deleteDC(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/deleteRemoteDataCenter"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/deleteRemoteDataCenter"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def delete(vmanage):
@@ -110,8 +107,8 @@ def delete(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/deregister"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/deregister"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def getDetails(vmanage):
@@ -126,8 +123,8 @@ def getDetails(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/details"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/details"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def download(vmanage, token):
@@ -143,8 +140,8 @@ def download(vmanage, token):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/download/backup/{token}/db_bkp.tar.gz"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/download/backup/{token}/db_bkp.tar.gz"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def downloadReplicationData(vmanage, token, fileName):
@@ -161,8 +158,8 @@ def downloadReplicationData(vmanage, token, fileName):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/download/{token}/{fileName}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/download/{token}/{fileName}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getDRStatus(vmanage):
@@ -177,8 +174,8 @@ def getDRStatus(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/drstatus"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/drstatus"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getHistory(vmanage):
@@ -193,8 +190,8 @@ def getHistory(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/history"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/history"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getLocalHistory(vmanage):
@@ -209,8 +206,8 @@ def getLocalHistory(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/localLatestHistory"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/localLatestHistory"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getLocalDCState(vmanage):
@@ -225,8 +222,8 @@ def getLocalDCState(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/localdc"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/localdc"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def pauseDR(vmanage):
@@ -241,8 +238,8 @@ def pauseDR(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/pause"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/pause"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def pauseLocalArbitrator(vmanage):
@@ -257,8 +254,8 @@ def pauseLocalArbitrator(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/pauseLocalArbitrator"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/pauseLocalArbitrator"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def pauseLocalDCForDR(vmanage):
@@ -273,8 +270,8 @@ def pauseLocalDCForDR(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/pauseLocalDC"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/pauseLocalDC"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def pauseLocalDCReplication(vmanage):
@@ -289,8 +286,8 @@ def pauseLocalDCReplication(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/pauseLocalReplication"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/pauseLocalReplication"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def DRPauseReplication(vmanage):
@@ -305,8 +302,8 @@ def DRPauseReplication(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/pausereplication"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/pausereplication"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def update(vmanage, request):
@@ -322,8 +319,8 @@ def update(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/register"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, request)
+    endpoint = f"dataservice/disasterrecovery/register"
+    response = vmanage.apiCall("PUT", endpoint, request)
     return response
 
 def register(vmanage, request):
@@ -339,8 +336,8 @@ def register(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/register"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/disasterrecovery/register"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 
 def getRemoteDCMembersState(vmanage):
@@ -355,8 +352,8 @@ def getRemoteDCMembersState(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/remoteDcState"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/remoteDcState"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getRemoteDataCenterState(vmanage):
@@ -371,8 +368,8 @@ def getRemoteDataCenterState(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/remotedc"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/remotedc"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def updateDRState(vmanage, dcReg):
@@ -388,8 +385,8 @@ def updateDRState(vmanage, dcReg):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/remotedc"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, dcReg)
+    endpoint = f"dataservice/disasterrecovery/remotedc"
+    response = vmanage.apiCall("POST", endpoint, dcReg)
     return response
 
 def getRemoteDCVersion(vmanage):
@@ -404,8 +401,8 @@ def getRemoteDCVersion(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/remotedc/swversion"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/remotedc/swversion"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def DRReplicationRequest(vmanage, drrequest):
@@ -421,8 +418,8 @@ def DRReplicationRequest(vmanage, drrequest):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/requestimport"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, drrequest)
+    endpoint = f"dataservice/disasterrecovery/requestimport"
+    response = vmanage.apiCall("POST", endpoint, drrequest)
     return response
 
 def restartDC(vmanage, dcReg):
@@ -438,8 +435,8 @@ def restartDC(vmanage, dcReg):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/restartDataCenter"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, dcReg)
+    endpoint = f"dataservice/disasterrecovery/restartDataCenter"
+    response = vmanage.apiCall("POST", endpoint, dcReg)
     return response
 
 def getDRLocalReplicationSchedule(vmanage):
@@ -454,8 +451,8 @@ def getDRLocalReplicationSchedule(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/schedule"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/schedule"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getdrStatus(vmanage):
@@ -470,8 +467,8 @@ def getdrStatus(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/status"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/disasterrecovery/status"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def unpauseDR(vmanage):
@@ -486,8 +483,8 @@ def unpauseDR(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/unpause"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/unpause"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def unpauseLocalArbitrator(vmanage):
@@ -502,8 +499,8 @@ def unpauseLocalArbitrator(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/unpauseLocalArbitrator"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/unpauseLocalArbitrator"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def unpauseLocalDCForDR(vmanage):
@@ -518,8 +515,8 @@ def unpauseLocalDCForDR(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/unpauseLocalDC"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/unpauseLocalDC"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def unpauseLocalDCReplication(vmanage):
@@ -534,8 +531,8 @@ def unpauseLocalDCReplication(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/unpauseLocalReplication"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/unpauseLocalReplication"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def DRUnPauseReplication(vmanage):
@@ -550,8 +547,8 @@ def DRUnPauseReplication(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/unpausereplication"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/unpausereplication"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def updateDrState(vmanage):
@@ -566,8 +563,8 @@ def updateDrState(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/updateDRConfigOnArbitrator"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/disasterrecovery/updateDRConfigOnArbitrator"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def updateReplication(vmanage, replicationstatus):
@@ -583,8 +580,8 @@ def updateReplication(vmanage, replicationstatus):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/updateReplication"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, replicationstatus)
+    endpoint = f"dataservice/disasterrecovery/updateReplication"
+    response = vmanage.apiCall("POST", endpoint, replicationstatus)
     return response
 
 def getReachabilityInfo(vmanage, nodelist):
@@ -600,6 +597,6 @@ def getReachabilityInfo(vmanage, nodelist):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/disasterrecovery/validateNodes"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, nodelist)
+    endpoint = f"dataservice/disasterrecovery/validateNodes"
+    response = vmanage.apiCall("POST", endpoint, nodelist)
     return response
