@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getSegments(vmanage):
     """
     Get network segments
@@ -13,8 +10,8 @@ def getSegments(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/segment"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/segment"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def createSegment(vmanage, segmen):
@@ -30,8 +27,8 @@ def createSegment(vmanage, segmen):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/segment"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, segmen)
+    endpoint = f"dataservice/segment"
+    response = vmanage.apiCall("POST", endpoint, segmen)
     return response
 
 def getSegment(vmanage, id):
@@ -47,8 +44,8 @@ def getSegment(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/segment/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/segment/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def editSegment(vmanage, segmen, id):
@@ -65,8 +62,8 @@ def editSegment(vmanage, segmen, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/segment/{id}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, segmen)
+    endpoint = f"dataservice/segment/{id}"
+    response = vmanage.apiCall("PUT", endpoint, segmen)
     return response
 
 def deleteSegment(vmanage, id):
@@ -82,6 +79,6 @@ def deleteSegment(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/segment/{id}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/segment/{id}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
