@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getAlarms(vmanage, deviceId):
     """
     Get hardware alarm list from device
@@ -14,8 +11,8 @@ def getAlarms(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/hardware/alarms?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/hardware/alarms?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getEnvironments(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getEnvironments(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/hardware/environment?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/hardware/environment?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getErrorAlarms(vmanage):
     """
@@ -45,8 +42,8 @@ def getErrorAlarms(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/hardware/errors"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/hardware/errors"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getInventory(vmanage, deviceId):
     """
@@ -61,8 +58,8 @@ def getInventory(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/hardware/inventory?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/hardware/inventory?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatusSummary(vmanage, deviceId):
     """
@@ -77,8 +74,8 @@ def getStatusSummary(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/hardware/status/summary?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/hardware/status/summary?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSyncAlarms(vmanage, deviceId):
     """
@@ -93,8 +90,8 @@ def getSyncAlarms(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/hardware/synced/alarms?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/hardware/synced/alarms?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSyncEnvironments(vmanage, deviceId):
     """
@@ -109,8 +106,8 @@ def getSyncEnvironments(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/hardware/synced/environment?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/hardware/synced/environment?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSyncInventory(vmanage, deviceId):
     """
@@ -125,8 +122,8 @@ def getSyncInventory(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/hardware/synced/inventory?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/hardware/synced/inventory?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSystem(vmanage, deviceId):
     """
@@ -141,8 +138,8 @@ def getSystem(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/hardware/system?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/hardware/system?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getTempThreshold(vmanage, deviceId):
     """
@@ -157,6 +154,6 @@ def getTempThreshold(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/hardware/threshold?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/hardware/threshold?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
