@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getInterface(vmanage, vpnId, ifname, mac, deviceId):
     """
     Get IPv6 Neighbors from device (Real Time)
@@ -17,6 +14,6 @@ def getInterface(vmanage, vpnId, ifname, mac, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ndv6?vpn-id={vpnId}&if-name={ifname}&mac={mac}&deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/ndv6?vpn-id={vpnId}&if-name={ifname}&mac={mac}&deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
